@@ -81,7 +81,6 @@ class Domoticz(IPlugin):
 				log.msg("index trouvé :  ***")
 				bodies = rs['boy']
 				log.msg("BODIES  :  %s" % (bodies))
-				log.msg("local  :  %s" % (local))
 				log.msg("number  :  %s" % (int(rs['idx'])))
 				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=devices&filter=temp&used=true&order=Name')
 				jsonreq = resp.json()
@@ -93,9 +92,9 @@ class Domoticz(IPlugin):
 						log.msg("*********  jsonreq - Temp   :  %s" % (rt['Temp']))
 #						log.msg("*********  jsonreq - Name   :  %s" % (rt['Name']))
 						log.msg("*********  jsonreq - Data   :  %s" % (rt['BatteryLevel']))
-						if local == "temperature" :
+						if location == "temperature" :
 							bodies = "la temperature a été trouvée et elle est de %s degré" % (rt['Temp'])
-						if local == "batterie" :
+						if location == "batterie" :
 							bodies = "le niveau de batterie a été trouvé et elle est de %s " % (rt['BatteryLevel'])
 		if bodies == "":
 			bodies = "j'ai rien compris aux devices"
